@@ -1,13 +1,14 @@
 package HTML::TreeBuilder::XPath;
 
 use List::Util qw( first);
+use Scalar::Util ();
 
 use strict;
 use warnings;
 
 use vars qw($VERSION);
 
-$VERSION = '0.11';
+$VERSION = '0.14';
 
 my %CHAR2DEFAULT_ENT= ( '&' => '&amp;', '<' => '&lt;', '>' => '&gt;', '"' => '&quot;');
 my %NUM2DEFAULT_ENT= ( '38' => 'amp', '60' => 'lt', '62' => 'gt', '"' => '&quot;');
@@ -131,6 +132,7 @@ sub getParentNode
     return $elt->{_parent} || bless { _root => $elt }, 'HTML::TreeBuilder::XPath::Root';
   }
 sub getName             { return shift->tag;   }
+sub getLocalName        { (my $name= $_[0]->tag) =~ s{^.*:}{}; $name; }
 sub getNextSibling      { my( $elt)= @_; 
                           my $parent= $elt->{_parent} || return undef;
                           return  $parent->_child_as_object( scalar $elt->right, ($elt->{_rank} || 0) + 1);
@@ -147,7 +149,7 @@ sub isTextNode          { return ref $_[0] ? 0 : 1; }
 
 sub getValue 
   { my $elt= shift;
-    if( $elt->isCommentNode) { return $elt->{_text}; }
+    if( $elt->isCommentNode) { return $elt->{text}; }
     return $elt->as_text;
   }
         
@@ -191,7 +193,7 @@ sub getAttributes
 sub to_number { return XML::XPathEngine::Number->new( $_[0]->as_text); }
 sub string_value 
   { my $elt= shift;
-    if( $elt->isCommentNode) { return $elt->{_text}; }
+    if( $elt->isCommentNode) { return $elt->{text}; }
     return $elt->as_text;
   };
 
@@ -206,6 +208,7 @@ sub _child_as_object
         $elt_or_text= bless { _content => $elt_or_text, _parent => $elt, }, 
                             'HTML::TreeBuilder::XPath::TextNode'
                       ;
+        Scalar::Util::weaken($elt_or_text->{_parent});
       }
     if( ref $rank) { warn "rank is a ", ref( $rank), " elt_or_text is a ", ref( $elt_or_text); } 
     $elt_or_text->{_rank}= $rank; # used for sorting;
@@ -466,6 +469,7 @@ sub string_value    { return $_[0]->{_value}; }
 sub to_number       { return XML::XPathEngine::Number->new( $_[0]->{_value}); }
 sub isAttributeNode { 1 }
 sub toString        { return qq{ $_[0]->{_name}="$_[0]->{_value}"}; }
+sub getAttributes   {  return $_[0]->{_elt}->getAttributes; }
 
 # awfully inefficient, but hopefully this is called only for weird (read test-case) queries
 sub getPreviousSibling
@@ -626,13 +630,17 @@ L<HTML::TreeBuilder>
 
 L<XML::XPathEngine>
 
+=head1 REPOSITORY
+
+L<https://github.com/mirod/HTML--TreeBuilder--XPath>
+
 =head1 AUTHOR
 
 Michel Rodriguez, E<lt>mirod@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Michel Rodriguez
+Copyright (C) 2006-2011 by Michel Rodriguez
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.4 or,
